==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/ToolChain/install_21_ExampleThreading.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_threading"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_queues" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1

INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_threading_queues.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LCD-screen"

  cat <<END_OF_ACTIVATE >>$File #{

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

activate.500_ttc_gpio.sh QUIET \"\$0\"
activate.500_ttc_i2c.sh QUIET \"\$0\"
activate.500_ttc_task.sh QUIET \"\$0\"
activate.500_ttc_queue.sh QUIET \"\$0\"
activate.500_ttc_memory.sh QUIET \"\$0\"

END_OF_ACTIVATE
#}
  
  createActivateScriptTail $File $Name
  #}

#}queues
  Name="${INSTALLPATH}_semaphores" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_${Name}=1
COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES
COMPILE_OPTS += -DconfigUSE_MUTEXES

INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_threading_semaphores.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}

  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LCD-screen"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{

activate.500_ttc_gpio.sh QUIET \"\$0\"
activate.500_ttc_i2c.sh QUIET \"\$0\"
activate.500_ttc_task.sh QUIET \"\$0\"
activate.500_ttc_queue.sh QUIET \"\$0\"
activate.500_ttc_memory.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}
  
#}semaphores
  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_21_ExampleThreading.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_threading"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_queues" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_threading_queues.o

# define font to use
COMPILE_OPTS += -DTTC_FONT1=font_type1_16x24

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Queues for boards with LCD-screen"

  cat <<END_OF_ACTIVATE >>$File #{

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

activate.500_ttc_gpio.sh   QUIET \"\$0\"
activate.500_ttc_i2c.sh    QUIET \"\$0\"
activate.500_ttc_task.sh   QUIET \"\$0\"
activate.500_ttc_queue.sh  QUIET \"\$0\"
activate.500_ttc_memory.sh QUIET \"\$0\"
activate.500_ttc_gfx.sh    QUIET "\$0"

# at least one font must be activated
activate.500_ttc_font__font_type1_16x24.sh QUIET "\$0"


END_OF_ACTIVATE
#}
  
  createActivateScriptTail $File $Name
  #}

#}queues
  Name="${INSTALLPATH}_semaphores" #{ 
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES
COMPILE_OPTS += -DconfigUSE_MUTEXES

INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_threading_semaphores.o

# define font to use
COMPILE_OPTS += -DTTC_FONT1=font_type1_16x24

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}

  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Examples of using Multitasking: Thread-synchronization/ -communication via Semaphores for boards with LCD-screen"
  echo 'rm 2>/dev/null $Dir_ExtensionsActive/makefile.600_example_*' >>$File
  
  # create links into extensions.active/
  #X ../scripts/printBaseExtensions.sh >>$File
  cat <<END_OF_ACTIVATE >>$File #{

activate.500_ttc_gpio.sh QUIET \"\$0\"
activate.500_ttc_i2c.sh QUIET \"\$0\"
activate.500_ttc_task.sh QUIET \"\$0\"
activate.500_ttc_queue.sh QUIET \"\$0\"
activate.500_ttc_memory.sh QUIET \"\$0\"
activate.500_ttc_gfx.sh    QUIET "\$0"

# at least one font must be activated
activate.500_ttc_font__font_type1_16x24.sh QUIET "\$0"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}
  
#}semaphores
  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
